@@ -470,6 +470,7 @@ private:
     std::optional<quint64> m_pendingWrite = std::nullopt;
 };
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 class KIOPluginFactory : public KIO::RealWorkerFactory
 {
     Q_OBJECT
@@ -491,5 +492,23 @@ public:
         return std::make_unique<AdminWorker>(QByteArrayLiteral("admin"), pool, app);
     }
 };
+#else
+
+class KIOPluginFactory : public KIO::WorkerFactory
+{
+    Q_OBJECT
+    Q_PLUGIN_METADATA(IID "org.kde.kio.worker.admin" FILE "admin.json")
+public:
+    std::unique_ptr<KIO::WorkerBase> createWorker(const QByteArray &pool, const QByteArray &app) override
+    {
+        qRegisterMetaType<KIO::UDSEntryList>("KIO::UDSEntryList");
+        qDBusRegisterMetaType<KIO::UDSEntryList>();
+        qRegisterMetaType<KIO::UDSEntry>("KIO::UDSEntry");
+        qDBusRegisterMetaType<KIO::UDSEntry>();
+        return std::make_unique<AdminWorker>(QByteArrayLiteral("admin"), pool, app);
+    }
+};
+
+#endif
 
 #include "worker.moc"
